@@ -46,14 +46,14 @@ class ArtifactEntry:
         self.local_path = local_path
 
     # ArtifactEntry 객체를 기반으로 파일 업로드 수행
-    def upload(self, upload_type: str, root_path: str, run_id: int, artifact_id: int, last_file_yn: str, artifact_digest: str, entry_list: List[grpc_ArtifactEntry]) -> bool:
+    def upload(self, upload_type: str, root_path: str, run_id: int, artifact_id: int, last_file_yn: str, teamName: str, expName: str, artifact_digest: str, entry_list: List[grpc_ArtifactEntry]) -> bool:
         assert_that(root_path).is_not_none()
         assert_that(run_id).is_not_none()
         assert_that(artifact_id).is_not_none()
         assert_that(last_file_yn).is_not_none()
         assert_that(artifact_digest).is_not_none()
         assert_that(entry_list).is_not_none()
-        return interface.upload_file(upload_type, self.local_path, root_path, self.path, run_id, artifact_id, last_file_yn, artifact_digest, self.digest, entry_list)
+        return interface.upload_file(upload_type, self.local_path, root_path, self.path, run_id, artifact_id, last_file_yn, teamName, expName, artifact_digest, self.digest, entry_list)
 
     def __str__(self) -> str:
         return f"{{path:{self.path},local_path:{self.local_path}}}"
@@ -132,7 +132,7 @@ class Artifact:
             ))
             hasher.update(f"{entry_path}:{entry.digest}\n".encode())
         artifact_digest = hasher.hexdigest()
-        id = interface.upload_artifact(run.run_id, self, artifact_digest, entry_list)
+        id = interface.upload_artifact(run.run_id, self, artifact_digest, run.team_name, run.exp_name, entry_list)
         if id is None:
             return False
         self.id = id
@@ -146,7 +146,7 @@ class Artifact:
                 upload_type = "ARTI_REPO"
             else:
                 upload_type = "ARTI_FILES"
-            succeeded = entry.upload(upload_type, root_path, run.run_id, self.id, last_file_yn, artifact_digest, entry_list)
+            succeeded = entry.upload(upload_type, root_path, run.run_id, self.id, last_file_yn,  run.team_name, run.exp_name, artifact_digest, entry_list)
             if not succeeded:
                 return False
         return True
