@@ -34,7 +34,23 @@ def upload_config():
     pass
 
 def upload_log(run_id: int, log_step: int, item_dict: Dict[str, Any]) -> bool:
-    item = [LogItem(key=key, value=str(value)) for key, value in item_dict.items()]
+    item_list = []
+    def makeItem(item) :
+        key, value = item
+        if isinstance(value, int) :
+            logItem = LogItem(key=key, valueAsInt =value)
+        elif isinstance(value, str) :
+            logItem = LogItem(key=key, valueAsString =value)
+        elif isinstance(value, float) :
+            logItem = LogItem(key=key, valueAsFloat =value)
+        elif isinstance(value, bool) :
+            logItem = LogItem(key=key, valueAsBool =value)
+        elif isinstance(value, long) :
+            logItem = LogItem(key=key, valueAsLong =value)
+        return logItem
+    item = map(makeItem, item_dict.items())
+
+    #item = [LogItem(key=key, value=str(value)) for key, value in item_dict.items()]
     rsp: UploadLogResponse = get_stub().upload_log(UploadLogRequest(
         item=item,
         step=LogStep(num=log_step),
@@ -45,7 +61,7 @@ def upload_log(run_id: int, log_step: int, item_dict: Dict[str, Any]) -> bool:
 
 CHUNK_SIZE = 1024 * 1024  # 1MB
 
-def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry]) -> UploadFileRequest:
+def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str, teamName: str, expName: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry]) -> UploadFileRequest:
     yield UploadFileRequest(
         uploadType = upload_type,
         file=FileRecord(file=FileItem(
@@ -59,6 +75,8 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
         digest=entry_digest,
         last_file_yn=last_file_yn,
         authorization=http_interface.get_jwt_key(),
+        teamName=teamName,
+        expName=expName,
         total_file_info=TotalFileInfo(
             digest=artifact_digest,
             entry=entry_list,
@@ -84,9 +102,9 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
                 ),
             )
 
-def upload_file( upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry]) -> bool:
+def upload_file( upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str,teamName: str, expName: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry]) -> bool:
 
-    rsp: UploadFileResponse = get_stub().upload_file(load_file(upload_type, local_path, root_path, path, run_id, artifact_id, last_file_yn, artifact_digest, entry_digest, entry_list))
+    rsp: UploadFileResponse = get_stub().upload_file(load_file(upload_type, local_path, root_path, path, run_id, artifact_id, last_file_yn, teamName, expName, artifact_digest, entry_digest, entry_list))
     return rsp.rsp_result.result == "success"
 
 def save_file(file_path: str, rsps) -> None:
@@ -106,7 +124,7 @@ def download_file(path: str, artifact_id: int, local_path: str):
         authorization=http_interface.get_jwt_key(),
     )))
 
-def upload_artifact(run_id: int, artifact: Artifact, artifact_digest: str, entry_list: List[ArtifactEntry]) -> int:
+def upload_artifact(run_id: int, artifact: Artifact, artifact_digest: str, teamName: str, expName: str,  entry_list: List[ArtifactEntry]) -> int:
     rsp: UploadArtifactResponse = get_stub().upload_artifact(UploadArtifactRequest(
         artifact=ArtifactRecord(
             run_id=run_id,
@@ -116,6 +134,8 @@ def upload_artifact(run_id: int, artifact: Artifact, artifact_digest: str, entry
             description=artifact.desc,
             versioning=artifact.versioning,
             metadata=json.dumps(artifact.meta_data),
+            teamName=teamName,
+            expName=expName,
             entry_list=entry_list,
         ),
         authorization=http_interface.get_jwt_key(),
