@@ -16,7 +16,7 @@ def use_artifact(name: str, type: str, tag: str="", team_name: str="", exp_name:
     artifact_id, artifact_record = get_run().use_artifact(name, type, tag, team_name, exp_name)
     entry_list = []
     for entry in artifact_record.entry_list:
-        entry_list.append(ArtifactEntry(entry.path, entry.local_path, entry.size, entry.digest))
+        entry_list.append(ArtifactEntry(entry.path, "", entry.size, entry.digest))
     return Artifact(artifact_record.name, artifact_record.type,
         id=artifact_id,
         desc=artifact_record.description,
